@@ -6,7 +6,7 @@
 */
 
 #pragma once
-
+#include "kcmutils_version.h"
 #include <KCModule>
 
 #include <QVariant>
@@ -18,7 +18,11 @@ class KCMAkregatorGeneralConfig : public KCModule
     Q_OBJECT
 
 public:
+#if KCMUTILS_VERSION < QT_VERSION_CHECK(5, 240, 0)
     explicit KCMAkregatorGeneralConfig(QWidget *parent, const QVariantList &args);
+#else
+    explicit KCMAkregatorGeneralConfig(QObject *parent, const KPluginMetaData &data, const QVariantList &args);
+#endif
 
 private:
     QWidget *const m_widget;
