@@ -1,5 +1,5 @@
 /*
-   SPDX-FileCopyrightText: 2020-2022 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2020-2023 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: GPL-2.0-or-later
 */
@@ -24,6 +24,6 @@ public:
     KUserFeedback::Provider *userFeedbackProvider() const;
 
 private:
-    KUserFeedback::Provider *mUserFeedbackProvider = nullptr;
+    KUserFeedback::Provider *const mUserFeedbackProvider;
 };
 }
